@@ -1,4 +1,4 @@
-C    Copyright(C) 1999-2020, 2023, 2024 National Technology & Engineering Solutions
+C    Copyright(C) 1999-2020, 2023, 2024, 2025 National Technology & Engineering Solutions
 C    of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
 C    NTESS, the U.S. Government retains certain rights in this software.
 C
@@ -170,7 +170,7 @@ C   --changing the table.
      4  'GVARS   ', 'NVARS   ', 'EVARS   ', 'NSVARS  ', 'SSVARS  ',
      5  '        ' /
       DATA LISTBL /
-     1  'TITLE   ', 'VARS    ', 'QAINFO  ', 'QA', 'INFORMATION', 
+     1  'TITLE   ', 'VARS    ', 'QAINFO  ', 'QA', 'INFORMATION',
      2  'COORDINA', 'MAP     ', 'NMAP    ', 'NODEMAP ',
      3  'BLOCKS  ', 'MATERIAL', 'LINK    ', 'CONNECTI', 'ATTRIBUT',
      4  'NSETS   ', 'NNODES  ', 'NFACTORS', 'INVCON  ',
@@ -375,8 +375,8 @@ C *** GENESIS Print Commands ***
           if (FFMATC (IFLD, INTYP, CFIELD, 'NSET', 4) .OR.
      *      FFMATC (IFLD, INTYP, CFIELD, 'NODESET', 7)) THEN
             CALL RIXID (DUMLIN, IFLD, INTYP, CFIELD, IFIELD,
-     &        'nodal point set ID',
-     &        NUMNPS, IDNPS, LISNPS(0), LISNPS(1), *270)
+     &        'nodal point set',
+     &        NUMNPS, IDNPS, LISNPS(0), LISNPS(1), NSNAME, *270)
             if (lisnps(0) .gt. 0) then
               call selset(lisnp(0), lisnp(1),
      *          numnps, lisnps, lnpsnl,
@@ -386,8 +386,8 @@ C *** GENESIS Print Commands ***
           else if (FFMATC (IFLD, INTYP, CFIELD, 'SSET', 4) .OR.
      *      FFMATC (IFLD, INTYP, CFIELD, 'SIDESET', 7)) THEN
             CALL RIXID (DUMLIN, IFLD, INTYP, CFIELD, IFIELD,
-     &        'side set ID',
-     &        NUMESS, IDESS, LISESS(0), LISESS(1), *270)
+     &        'side set',
+     &        NUMESS, IDESS, LISESS(0), LISESS(1), SSNAME, *270)
             if (lisess(0) .gt. 0) then
                CALL MDRSRV ('SCR',    KSCR,  NUMNP)
               call selssetn(lisnp(0), lisnp(1),
@@ -403,8 +403,8 @@ C *** GENESIS Print Commands ***
             IF (NERR .GT. 0) GOTO 280
 
             CALL RIXID (DUMLIN, IFLD, INTYP, CFIELD, IFIELD,
-     &        'element block ID',
-     &        NELBLK, IDELB, IA(KLELB), IA(KLELB+1), *205)
+     &           'element block',
+     &           NELBLK, IDELB, IA(KLELB), IA(KLELB+1), EBNAME, *205)
  205        continue
             if (IA(KLELB) .gt. 0) then
               call selblk(lisnp(0), lisnp(1),
@@ -441,8 +441,8 @@ C *** GENESIS Print Commands ***
           if (FFMATC (IFLD, INTYP, CFIELD, 'SSET', 4) .OR.
      *      FFMATC (IFLD, INTYP, CFIELD, 'SIDESET', 7)) THEN
             CALL RIXID (DUMLIN, IFLD, INTYP, CFIELD, IFIELD,
-     &        'side set ID',
-     &        NUMESS, IDESS, LISESS(0), LISESS(1), *270)
+     &        'side set',
+     &        NUMESS, IDESS, LISESS(0), LISESS(1), SSNAME, *270)
             if (lisess(0) .gt. 0) then
               call selset(IA(KLEL), IA(KLEL+1),
      *          numess, lisess, lessel,
@@ -476,11 +476,10 @@ C *** GENESIS Print Commands ***
           IF (NERR .GT. 0) GOTO 280
 
           CALL RIXID (DUMLIN, IFLD, INTYP, CFIELD, IFIELD,
-     &      'element block ID',
-     &      NELBLK, IDELB, IA(KLELB), IA(KLELB+1), *220)
+     &         'element block',
+     &         NELBLK, IDELB, IA(KLELB), IA(KLELB+1), EBNAME, *220)
  220      CONTINUE
-
-          CALL DBSELB (NELBLK, NUMEL, LENE, A(KLELB),
+          CALL DBSELB (NELBLK, NUMEL, LENE, IA(KLELB),
      &      NLISEL, LISEL)
 
           CALL MDDEL ('SCRSEL')
@@ -491,8 +490,8 @@ C *** GENESIS Print Commands ***
           CALL CKNONE (NUMNPS, .FALSE., 'nodal point sets', *270)
 
           CALL RIXID (DUMLIN, IFLD, INTYP, CFIELD, IFIELD,
-     &      'nodal point set ID',
-     &      NUMNPS, IDNPS, LISNPS(0), LISNPS(1), *270)
+     &         'nodal point set',
+     &         NUMNPS, IDNPS, LISNPS(0), LISNPS(1), NSNAME, *270)
 
         ELSE IF (LISTYP .EQ. 'SSETS') THEN
           NSTEPSS = -1
@@ -500,8 +499,8 @@ C *** GENESIS Print Commands ***
           CALL CKNONE (NUMESS, .FALSE., 'element side sets', *270)
 
           CALL RIXID (DUMLIN, IFLD, INTYP, CFIELD, IFIELD,
-     &      'element side set ID',
-     &      NUMESS, IDESS, LISESS(0), LISESS(1), *270)
+     &         'element side set',
+     &         NUMESS, IDESS, LISESS(0), LISESS(1), SSNAME, *270)
 
 C *** EXODUS Movement Commands ***
 
