@@ -1,5 +1,5 @@
 /*
- * Copyright(C) 1999-2022 National Technology & Engineering Solutions
+ * Copyright(C) 1999-2024 National Technology & Engineering Solutions
  * of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
  * NTESS, the U.S. Government retains certain rights in this software.
  *
@@ -16,29 +16,29 @@ static int exi_get_dimension_value(int exoid, int64_t *var, int default_value,
   int status;
   int dimid;
 
-  if ((status = nc_inq_dimid(exoid, dimension_name, &dimid)) != NC_NOERR) {
+  if ((status = nc_inq_dimid(exoid, dimension_name, &dimid)) != EX_NOERR) {
     *var = default_value;
     if (missing_ok) {
-      return (EX_NOERR);
+      return EX_NOERR;
     }
     char errmsg[MAX_ERR_LENGTH];
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to retrieve dimension %s for file id %d",
              dimension_name, exoid);
     ex_err_fn(exoid, __func__, errmsg, status);
-    return (EX_FATAL);
+    return EX_FATAL;
   }
   size_t idum;
-  if ((status = nc_inq_dimlen(exoid, dimid, &idum)) != NC_NOERR) {
+  if ((status = nc_inq_dimlen(exoid, dimid, &idum)) != EX_NOERR) {
     *var = default_value;
     char errmsg[MAX_ERR_LENGTH];
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to retrieve value for dimension %s for file id %d", dimension_name,
              exoid);
     ex_err_fn(exoid, __func__, errmsg, status);
-    return (EX_FATAL);
+    return EX_FATAL;
   }
   *var = idum;
-  return (EX_NOERR);
+  return EX_NOERR;
 }
 
 static int ex_get_concat_set_len(int exoid, int64_t *set_length, const char *set_name,
@@ -48,15 +48,15 @@ static int ex_get_concat_set_len(int exoid, int64_t *set_length, const char *set
   *set_length = 0; /* default return value */
 
   int dimid;
-  if (nc_inq_dimid(exoid, set_num_dim, &dimid) == NC_NOERR) {
+  if (nc_inq_dimid(exoid, set_num_dim, &dimid) == EX_NOERR) {
     int    status;
     size_t num_sets;
-    if ((status = nc_inq_dimlen(exoid, dimid, &num_sets)) != NC_NOERR) {
+    if ((status = nc_inq_dimlen(exoid, dimid, &num_sets)) != EX_NOERR) {
       char errmsg[MAX_ERR_LENGTH];
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of %s sets in file id %d",
                set_name, exoid);
       ex_err_fn(exoid, __func__, errmsg, status);
-      return (EX_FATAL);
+      return EX_FATAL;
     }
 
     /* Allocate space for stat array */
@@ -68,21 +68,21 @@ static int ex_get_concat_set_len(int exoid, int64_t *set_length, const char *set
                "array for file id %d",
                set_name, exoid);
       ex_err_fn(exoid, __func__, errmsg, EX_MEMFAIL);
-      return (EX_FATAL);
+      return EX_FATAL;
     }
 
     /* get variable id of status array */
     int varid;
-    if (nc_inq_varid(exoid, set_stat_var, &varid) == NC_NOERR) {
+    if (nc_inq_varid(exoid, set_stat_var, &varid) == EX_NOERR) {
       /* if status array exists, use it, otherwise assume, object exists
          to be backward compatible */
-      if ((status = nc_get_var_int(exoid, varid, stat_vals)) != NC_NOERR) {
+      if ((status = nc_get_var_int(exoid, varid, stat_vals)) != EX_NOERR) {
         free(stat_vals);
         char errmsg[MAX_ERR_LENGTH];
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get %s set status array from file id %d",
                  set_name, exoid);
         ex_err_fn(exoid, __func__, errmsg, status);
-        return (EX_FATAL);
+        return EX_FATAL;
       }
     }
     else { /* default: status is true */
@@ -97,21 +97,21 @@ static int ex_get_concat_set_len(int exoid, int64_t *set_length, const char *set
       }
 
       size_t idum;
-      if (nc_inq_dimid(exoid, exi_catstr(set_size_root, i + 1), &dimid) != NC_NOERR) {
+      if (nc_inq_dimid(exoid, exi_catstr(set_size_root, i + 1), &dimid) != EX_NOERR) {
         if (missing_ok) {
           idum = 0;
         }
         else {
           *set_length = 0;
           free(stat_vals);
-          return (EX_FATAL);
+          return EX_FATAL;
         }
       }
       else {
-        if (nc_inq_dimlen(exoid, dimid, &idum) != NC_NOERR) {
+        if (nc_inq_dimlen(exoid, dimid, &idum) != EX_NOERR) {
           *set_length = 0;
           free(stat_vals);
-          return (EX_FATAL);
+          return EX_FATAL;
         }
       }
 
@@ -120,7 +120,7 @@ static int ex_get_concat_set_len(int exoid, int64_t *set_length, const char *set
 
     free(stat_vals);
   }
-  return (EX_NOERR);
+  return EX_NOERR;
 }
 
 static void flt_cvt(float *xptr, double x) { *xptr = (float)x; }
@@ -138,7 +138,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
   int    num_var;
 
   if (exi_check_valid_file_id(exoid, __func__) == EX_FATAL) {
-    return (EX_FATAL);
+    return EX_FATAL;
   }
 
   if (ret_char) {
@@ -147,7 +147,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
   if (!ret_int) {
     snprintf(errmsg, MAX_ERR_LENGTH, "Warning: integer argument is NULL which is not allowed.");
     ex_err_fn(exoid, __func__, errmsg, EX_BADPARAM);
-    return (EX_FATAL);
+    return EX_FATAL;
   }
 
   int rootid = exoid & EX_FILE_ID_MASK;
@@ -156,10 +156,10 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
   case EX_INQ_FILE_TYPE:
 
     /* obsolete call */
-    /*returns "r" for regular EXODUS file or "h" for history EXODUS file*/
+    /*return "r" for regular EXODUS file or "h" for history EXODUS file*/
     snprintf(errmsg, MAX_ERR_LENGTH, "Warning: file type inquire is obsolete");
     ex_err_fn(exoid, __func__, errmsg, EX_BADPARAM);
-    return (EX_WARN);
+    return EX_WARN;
 
   case EX_INQ_API_VERS:
     /* returns the EXODUS API version number */
@@ -168,17 +168,17 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
                "Warning: float argument is NULL for EX_INQ_API_VERS "
                "which is not allowed.");
       ex_err_fn(exoid, __func__, errmsg, EX_BADPARAM);
-      return (EX_FATAL);
+      return EX_FATAL;
     }
 
     if (nc_get_att_float(rootid, NC_GLOBAL, ATT_API_VERSION, ret_float) !=
-        NC_NOERR) { /* try old (prior to db version 2.02) attribute name */
+        EX_NOERR) { /* try old (prior to db version 2.02) attribute name */
       if ((status = nc_get_att_float(rootid, NC_GLOBAL, ATT_API_VERSION_BLANK, ret_float)) !=
-          NC_NOERR) {
+          EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get EXODUS API version for file id %d",
                  rootid);
         ex_err_fn(exoid, __func__, errmsg, status);
-        return (EX_FATAL);
+        return EX_FATAL;
       }
     }
 
@@ -191,14 +191,14 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
                "Warning: float argument is NULL for EX_INQ_DB_VERS "
                "which is not allowed.");
       ex_err_fn(exoid, __func__, errmsg, EX_BADPARAM);
-      return (EX_FATAL);
+      return EX_FATAL;
     }
 
-    if ((status = nc_get_att_float(rootid, NC_GLOBAL, ATT_VERSION, ret_float)) != NC_NOERR) {
+    if ((status = nc_get_att_float(rootid, NC_GLOBAL, ATT_VERSION, ret_float)) != EX_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to get EXODUS database version for file id %d", rootid);
       ex_err_fn(exoid, __func__, errmsg, status);
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     break;
 
@@ -219,18 +219,18 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
        It will not include the space for the trailing null, so if it
        is defined as 33 on the database, 32 will be returned.
     */
-    if (nc_inq_dimid(rootid, DIM_STR_NAME, &dimid) != NC_NOERR) {
+    if (nc_inq_dimid(rootid, DIM_STR_NAME, &dimid) != EX_NOERR) {
       /* If not found, then an older database */
       *ret_int = 32;
     }
     else {
       /* Get the name string length */
       size_t name_length = 0;
-      if ((status = nc_inq_dimlen(rootid, dimid, &name_length)) != NC_NOERR) {
+      if ((status = nc_inq_dimlen(rootid, dimid, &name_length)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get name string length in file id %d",
                  exoid);
         ex_err_fn(exoid, __func__, errmsg, status);
-        return (EX_FATAL);
+        return EX_FATAL;
       }
 
       *ret_int = name_length - 1;
@@ -255,7 +255,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
       *ret_int = 32; /* Default size consistent with older databases */
 
       status = nc_inq_att(rootid, NC_GLOBAL, ATT_MAX_NAME_LENGTH, &att_type, &att_len);
-      if (status == NC_NOERR && att_type == NC_INT) {
+      if (status == EX_NOERR && att_type == NC_INT) {
         /* The attribute exists, return it... */
         nc_get_att_longlong(rootid, NC_GLOBAL, ATT_MAX_NAME_LENGTH, (long long *)ret_int);
       }
@@ -288,18 +288,18 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
                "for file id %d",
                rootid);
       ex_err_fn(exoid, __func__, errmsg, EX_BADPARAM);
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     else {
       /* returns the title of the database */
       /* Title is stored at root level... */
       char tmp_title[2048];
-      if ((status = nc_get_att_text(rootid, NC_GLOBAL, ATT_TITLE, tmp_title)) != NC_NOERR) {
+      if ((status = nc_get_att_text(rootid, NC_GLOBAL, ATT_TITLE, tmp_title)) != EX_NOERR) {
         *ret_char = '\0';
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get database title for file id %d",
                  exoid);
         ex_err_fn(exoid, __func__, errmsg, status);
-        return (EX_FATAL);
+        return EX_FATAL;
       }
       ex_copy_string(ret_char, tmp_title, MAX_LINE_LENGTH + 1);
     }
@@ -308,8 +308,8 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
   case EX_INQ_DIM:
     /* returns the dimensionality (2 or 3, for 2-d or 3-d) of the database */
     if (exi_get_dimension(exoid, DIM_NUM_DIM, "database dimensionality", &ldum, &dimid, __func__) !=
-        NC_NOERR) {
-      return (EX_FATAL);
+        EX_NOERR) {
+      return EX_FATAL;
     }
     *ret_int = ldum;
     break;
@@ -338,7 +338,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
   case EX_INQ_NODES:
     /* returns the number of nodes */
-    if (exi_get_dimension(exoid, DIM_NUM_NODES, "nodes", &ldum, &dimid, NULL) != NC_NOERR) {
+    if (exi_get_dimension(exoid, DIM_NUM_NODES, "nodes", &ldum, &dimid, NULL) != EX_NOERR) {
       *ret_int = 0;
     }
     else {
@@ -348,7 +348,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
   case EX_INQ_ELEM:
     /* returns the number of elements */
-    if (exi_get_dimension(exoid, DIM_NUM_ELEM, "elements", &ldum, &dimid, NULL) != NC_NOERR) {
+    if (exi_get_dimension(exoid, DIM_NUM_ELEM, "elements", &ldum, &dimid, NULL) != EX_NOERR) {
       *ret_int = 0;
     }
     else {
@@ -359,7 +359,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
   case EX_INQ_ELEM_BLK:
     /* returns the number of element blocks */
     if (exi_get_dimension(exoid, DIM_NUM_EL_BLK, "element blocks", &ldum, &dimid, NULL) !=
-        NC_NOERR) {
+        EX_NOERR) {
       *ret_int = 0;
     }
     else {
@@ -369,7 +369,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
   case EX_INQ_NODE_SETS:
     /* returns the number of node sets */
-    if (exi_get_dimension(exoid, DIM_NUM_NS, "node sets", &ldum, &dimid, NULL) != NC_NOERR) {
+    if (exi_get_dimension(exoid, DIM_NUM_NS, "node sets", &ldum, &dimid, NULL) != EX_NOERR) {
       *ret_int = 0;
     }
     else {
@@ -397,16 +397,16 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
     *ret_int = 0; /* default value if no node sets defined */
 
-    if (nc_inq_dimid(exoid, DIM_NUM_NS, &dimid) == NC_NOERR) {
-      if ((status = nc_inq_dimlen(exoid, dimid, &num_sets)) != NC_NOERR) {
+    if (nc_inq_dimid(exoid, DIM_NUM_NS, &dimid) == EX_NOERR) {
+      if ((status = nc_inq_dimlen(exoid, dimid, &num_sets)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of node sets in file id %d",
                  exoid);
         ex_err_fn(exoid, __func__, errmsg, status);
-        return (EX_FATAL);
+        return EX_FATAL;
       }
 
       for (size_t i = 0; i < num_sets; i++) {
-        if ((status = nc_inq_varid(exoid, VAR_FACT_NS(i + 1), &varid)) != NC_NOERR) {
+        if ((status = nc_inq_varid(exoid, VAR_FACT_NS(i + 1), &varid)) != EX_NOERR) {
           if (status == NC_ENOTVAR) {
             idum = 0; /* this dist factor doesn't exist */
           }
@@ -417,25 +417,25 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
                 "ERROR: failed to locate number of dist fact for %zu'th node set in file id %d", i,
                 exoid);
             ex_err_fn(exoid, __func__, errmsg, status);
-            return (EX_FATAL);
+            return EX_FATAL;
           }
         }
         else {
-          if ((status = nc_inq_dimid(exoid, DIM_NUM_NOD_NS(i + 1), &dimid)) != NC_NOERR) {
+          if ((status = nc_inq_dimid(exoid, DIM_NUM_NOD_NS(i + 1), &dimid)) != EX_NOERR) {
             *ret_int = 0;
             snprintf(errmsg, MAX_ERR_LENGTH,
                      "ERROR: failed to locate number of nodes in %zu'th node set in file id %d", i,
                      exoid);
             ex_err_fn(exoid, __func__, errmsg, status);
-            return (EX_FATAL);
+            return EX_FATAL;
           }
-          if ((status = nc_inq_dimlen(exoid, dimid, &idum)) != NC_NOERR) {
+          if ((status = nc_inq_dimlen(exoid, dimid, &idum)) != EX_NOERR) {
             *ret_int = 0;
             snprintf(errmsg, MAX_ERR_LENGTH,
                      "ERROR: failed to get number of nodes in %zu'th node set in file id %d", i,
                      exoid);
             ex_err_fn(exoid, __func__, errmsg, status);
-            return (EX_FATAL);
+            return EX_FATAL;
           }
         }
         *ret_int += idum;
@@ -446,7 +446,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
   case EX_INQ_SIDE_SETS:
     /* returns the number of side sets */
-    if (exi_get_dimension(exoid, DIM_NUM_SS, "side sets", &ldum, &dimid, NULL) != NC_NOERR) {
+    if (exi_get_dimension(exoid, DIM_NUM_SS, "side sets", &ldum, &dimid, NULL) != EX_NOERR) {
       *ret_int = 0;
     }
     else {
@@ -460,12 +460,12 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
     *ret_int = 0; /* default return value */
 
-    if (nc_inq_dimid(exoid, DIM_NUM_SS, &dimid) == NC_NOERR) {
-      if ((status = nc_inq_dimlen(exoid, dimid, &num_sets)) != NC_NOERR) {
+    if (nc_inq_dimid(exoid, DIM_NUM_SS, &dimid) == EX_NOERR) {
+      if ((status = nc_inq_dimlen(exoid, dimid, &num_sets)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of side sets in file id %d",
                  exoid);
         ex_err_fn(exoid, __func__, errmsg, status);
-        return (EX_FATAL);
+        return EX_FATAL;
       }
 
       int *ids = NULL;
@@ -474,14 +474,14 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to allocate memory for side set ids for file id %d", exoid);
         ex_err_fn(exoid, __func__, errmsg, EX_MEMFAIL);
-        return (EX_FATAL);
+        return EX_FATAL;
       }
 
       if (ex_get_ids(exoid, EX_SIDE_SET, ids) == EX_FATAL) {
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get side set ids in file id %d", exoid);
         ex_err_fn(exoid, __func__, errmsg, EX_LASTERR);
         free(ids);
-        return (EX_FATAL);
+        return EX_FATAL;
       }
 
       /* allocate space for stat array */
@@ -492,20 +492,20 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
                  "array for file id %d",
                  exoid);
         ex_err_fn(exoid, __func__, errmsg, EX_MEMFAIL);
-        return (EX_FATAL);
+        return EX_FATAL;
       }
       /* get variable id of status array */
-      if (nc_inq_varid(exoid, VAR_SS_STAT, &varid) == NC_NOERR) {
+      if (nc_inq_varid(exoid, VAR_SS_STAT, &varid) == EX_NOERR) {
         /* if status array exists, use it, otherwise assume, object exists
            to be backward compatible */
 
-        if ((status = nc_get_var_int(exoid, varid, stat_vals)) != NC_NOERR) {
+        if ((status = nc_get_var_int(exoid, varid, stat_vals)) != EX_NOERR) {
           free(ids);
           free(stat_vals);
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to get element block status array from file id %d", exoid);
           ex_err_fn(exoid, __func__, errmsg, status);
-          return (EX_FATAL);
+          return EX_FATAL;
         }
       }
       else { /* default: status is true */
@@ -546,7 +546,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
           ex_err_fn(exoid, __func__, errmsg, status);
           free(stat_vals);
           free(ids);
-          return (EX_FATAL);
+          return EX_FATAL;
         }
       }
 
@@ -578,16 +578,16 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
     /* first check see if any side sets exist */
 
-    if (nc_inq_dimid(exoid, DIM_NUM_SS, &dimid) == NC_NOERR) {
-      if ((status = nc_inq_dimlen(exoid, dimid, &num_sets)) != NC_NOERR) {
+    if (nc_inq_dimid(exoid, DIM_NUM_SS, &dimid) == EX_NOERR) {
+      if ((status = nc_inq_dimlen(exoid, dimid, &num_sets)) != EX_NOERR) {
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of side sets in file id %d",
                  exoid);
         ex_err_fn(exoid, __func__, errmsg, status);
-        return (EX_FATAL);
+        return EX_FATAL;
       }
 
       for (size_t i = 0; i < num_sets; i++) {
-        if ((status = nc_inq_dimid(exoid, DIM_NUM_DF_SS(i + 1), &dimid)) != NC_NOERR) {
+        if ((status = nc_inq_dimid(exoid, DIM_NUM_DF_SS(i + 1), &dimid)) != EX_NOERR) {
           if (status == NC_EBADDIM) {
             ldum = 0; /* this dist factor doesn't exist */
           }
@@ -598,17 +598,17 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
                 "ERROR: failed to locate number of dist fact for %zu'th side set in file id %d", i,
                 exoid);
             ex_err_fn(exoid, __func__, errmsg, status);
-            return (EX_FATAL);
+            return EX_FATAL;
           }
         }
         else {
-          if ((status = nc_inq_dimlen(exoid, dimid, &ldum)) != NC_NOERR) {
+          if ((status = nc_inq_dimlen(exoid, dimid, &ldum)) != EX_NOERR) {
             *ret_int = 0;
             snprintf(errmsg, MAX_ERR_LENGTH,
                      "ERROR: failed to get number of dist factors in %zu'th side set in file id %d",
                      i, exoid);
             ex_err_fn(exoid, __func__, errmsg, status);
-            return (EX_FATAL);
+            return EX_FATAL;
           }
         }
         *ret_int += ldum;
@@ -619,7 +619,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
   case EX_INQ_QA:
     /* returns the number of QA records */
-    if (exi_get_dimension(rootid, DIM_NUM_QA, "QA records", &ldum, &dimid, NULL) != NC_NOERR) {
+    if (exi_get_dimension(rootid, DIM_NUM_QA, "QA records", &ldum, &dimid, NULL) != EX_NOERR) {
       *ret_int = 0;
     }
     else {
@@ -629,7 +629,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
   case EX_INQ_INFO:
     /* returns the number of information records */
-    if (exi_get_dimension(rootid, DIM_NUM_INFO, "info records", &ldum, &dimid, NULL) != NC_NOERR) {
+    if (exi_get_dimension(rootid, DIM_NUM_INFO, "info records", &ldum, &dimid, NULL) != EX_NOERR) {
       *ret_int = 0;
     }
     else {
@@ -639,8 +639,8 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
   case EX_INQ_TIME:
     /*     returns the number of time steps stored in the database */
-    if (exi_get_dimension(exoid, DIM_TIME, "time dimension", &ldum, &dimid, __func__) != NC_NOERR) {
-      return (EX_FATAL);
+    if (exi_get_dimension(exoid, DIM_TIME, "time dimension", &ldum, &dimid, __func__) != EX_NOERR) {
+      return EX_FATAL;
     }
     *ret_int = ldum;
     break;
@@ -662,7 +662,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
   case EX_INQ_ELEM_MAP:
     /* returns the number of element maps */
-    if (exi_get_dimension(exoid, DIM_NUM_EM, "element maps", &ldum, &dimid, NULL) != NC_NOERR) {
+    if (exi_get_dimension(exoid, DIM_NUM_EM, "element maps", &ldum, &dimid, NULL) != EX_NOERR) {
       *ret_int = 0;
     }
     else {
@@ -677,7 +677,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
 
   case EX_INQ_NODE_MAP:
     /* returns the number of node maps */
-    if (exi_get_dimension(exoid, DIM_NUM_NM, "node maps", &ldum, &dimid, NULL) != NC_NOERR) {
+    if (exi_get_dimension(exoid, DIM_NUM_NM, "node maps", &ldum, &dimid, NULL) != EX_NOERR) {
       *ret_int = 0;
     }
     else {
@@ -693,21 +693,21 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
   case EX_INQ_EDGE:
     /* returns the number of edges (defined across all edge blocks). */
     if (exi_get_dimension_value(exoid, ret_int, 0, DIM_NUM_EDGE, 1) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     break;
 
   case EX_INQ_EDGE_BLK:
     /* returns the number of edge blocks. */
     if (exi_get_dimension_value(exoid, ret_int, 0, DIM_NUM_ED_BLK, 1) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     break;
 
   case EX_INQ_EDGE_SETS:
     /* returns the number of edge sets. */
     if (exi_get_dimension_value(exoid, ret_int, 0, DIM_NUM_ES, 1) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     break;
 
@@ -737,21 +737,21 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
   case EX_INQ_FACE:
     /* returns the number of faces (defined across all face blocks). */
     if (exi_get_dimension_value(exoid, ret_int, 0, DIM_NUM_FACE, 1) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     break;
 
   case EX_INQ_FACE_BLK:
     /* returns the number of face blocks. */
     if (exi_get_dimension_value(exoid, ret_int, 0, DIM_NUM_FA_BLK, 1) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     break;
 
   case EX_INQ_FACE_SETS:
     /* returns the number of face sets. */
     if (exi_get_dimension_value(exoid, ret_int, 0, DIM_NUM_FS, 1) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     break;
 
@@ -781,7 +781,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
   case EX_INQ_ELEM_SETS:
     /* returns the number of element sets. */
     if (exi_get_dimension_value(exoid, ret_int, 0, DIM_NUM_ELS, 1) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     break;
 
@@ -804,83 +804,83 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
   case EX_INQ_EDGE_MAP:
     /* returns the number of edge maps. */
     if (exi_get_dimension_value(exoid, ret_int, 0, DIM_NUM_EDM, 1) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     break;
 
   case EX_INQ_FACE_MAP:
     /*     returns the number of face maps. */
     if (exi_get_dimension_value(exoid, ret_int, 0, DIM_NUM_FAM, 1) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     break;
 
   case EX_INQ_NUM_NODE_VAR:
     if (ex_get_variable_param(exoid, EX_NODAL, &num_var) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     *ret_int = num_var;
     break;
 
   case EX_INQ_NUM_EDGE_BLOCK_VAR:
     if (ex_get_variable_param(exoid, EX_EDGE_BLOCK, &num_var) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     *ret_int = num_var;
     break;
 
   case EX_INQ_NUM_FACE_BLOCK_VAR:
     if (ex_get_variable_param(exoid, EX_FACE_BLOCK, &num_var) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     *ret_int = num_var;
     break;
 
   case EX_INQ_NUM_ELEM_BLOCK_VAR:
     if (ex_get_variable_param(exoid, EX_ELEM_BLOCK, &num_var) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     *ret_int = num_var;
     break;
 
   case EX_INQ_NUM_NODE_SET_VAR:
     if (ex_get_variable_param(exoid, EX_NODE_SET, &num_var) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     *ret_int = num_var;
     break;
 
   case EX_INQ_NUM_EDGE_SET_VAR:
     if (ex_get_variable_param(exoid, EX_EDGE_SET, &num_var) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     *ret_int = num_var;
     break;
 
   case EX_INQ_NUM_FACE_SET_VAR:
     if (ex_get_variable_param(exoid, EX_FACE_SET, &num_var) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     *ret_int = num_var;
     break;
 
   case EX_INQ_NUM_ELEM_SET_VAR:
     if (ex_get_variable_param(exoid, EX_ELEM_SET, &num_var) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     *ret_int = num_var;
     break;
 
   case EX_INQ_NUM_SIDE_SET_VAR:
     if (ex_get_variable_param(exoid, EX_SIDE_SET, &num_var) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     *ret_int = num_var;
     break;
 
   case EX_INQ_NUM_GLOBAL_VAR:
     if (ex_get_variable_param(exoid, EX_GLOBAL, &num_var) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     *ret_int = num_var;
     break;
@@ -888,7 +888,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
   case EX_INQ_COORD_FRAMES:
     /* return the number of coordinate frames */
     if (exi_get_dimension_value(exoid, ret_int, 0, DIM_NUM_CFRAMES, 1) != EX_NOERR) {
-      return (EX_FATAL);
+      return EX_FATAL;
     }
     break;
 
@@ -936,7 +936,7 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
                "null for file id %d",
                exoid);
       ex_err_fn(exoid, __func__, errmsg, EX_BADPARAM);
-      return (EX_FATAL);
+      return EX_FATAL;
     }
 #if NC_HAS_HDF5
     nc_inq_grpname(exoid, ret_char);
@@ -968,13 +968,21 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
                "null for file id %d",
                exoid);
       ex_err_fn(exoid, __func__, errmsg, EX_BADPARAM);
-      return (EX_FATAL);
+      return EX_FATAL;
     }
 #if NC_HAS_HDF5
     nc_inq_grpname_full(exoid, NULL, ret_char);
 #endif
     break;
 
+  case EX_INQ_FILE_FORMAT: {
+    /* return netCDF file format.
+     */
+    int nc_format = 0;
+    nc_inq_format(exoid, &nc_format);
+    *ret_int = nc_format;
+  } break;
+
   case EX_INQ_THREADSAFE:
 /* Return 1 if the library was compiled in thread-safe mode.
  * Return 0 otherwise
@@ -990,9 +998,9 @@ static int ex_inquire_internal(int exoid, int req_info, int64_t *ret_int, float
     *ret_int = 0;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: invalid inquiry %d", req_info);
     ex_err_fn(exoid, __func__, errmsg, EX_BADPARAM);
-    return (EX_FATAL);
+    return EX_FATAL;
   }
-  return (EX_NOERR);
+  return EX_NOERR;
 }
 
 /*!
