@@ -1,5 +1,5 @@
 /*
- * Copyright(C) 1999-2024 National Technology & Engineering Solutions
+ * Copyright(C) 1999-2025 National Technology & Engineering Solutions
  * of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
  * NTESS, the U.S. Government retains certain rights in this software.
  *
@@ -35,7 +35,8 @@ namespace IOShell {
     std::string              outputFile;
     std::string              inFiletype{"unknown"};
     std::string              outFiletype{"unknown"};
-    std::string              groupName;
+    std::string              changeSetName;
+    std::string              selectedChangeSets;
     std::string              decomp_method;
     std::string              decomp_extra{"processor_id"};
     std::string              compose_output{"default"};
@@ -53,17 +54,29 @@ namespace IOShell {
     int                      surface_split_type{-1};
     int                      data_storage_type{0};
     int                      compression_level{0};
+    int                      quantize_nsd{0};
     int                      serialize_io_size{0};
     int                      flush_interval{0};
 
     //! If non-empty, then it is a list of times that should be transferred to the output file.
     std::vector<double> selected_times{};
 
+    //! If non-empty, then it is a list of steps that should be transferred to the output file.
+    //  A negative value counts from end. -1 is last, -2 is second last...
+    std::vector<int> selected_steps{};
+
     //! If non-empty, then it is a list of element blocks, nodesets,
     //! sidesets that should be omitted from the output file
     std::vector<std::string> omitted_blocks{};
     std::vector<std::string> omitted_sets{};
 
+    //! If non-empty, a list of element block ids and/or names that
+    //! should be omitted in a parallel decomposition. The blocks will
+    //! still appear in the decomposed files, but will not affect the
+    //! balance. Only active element blocks will be load-balanced.
+    std::vector<int> decomp_omitted_block_ids{};
+    std::string      decomp_omitted_block_names{};
+
     //! If non-zero, then put `split_times` timesteps in each file. Then close file and start new
     //! file.
     // If `split_cyclic == 0`, then filenames will be
@@ -78,8 +91,11 @@ namespace IOShell {
     // -> file.A, t=7,8 -> file.B
     int  split_cyclic{0};
     bool shuffle{false};
-    bool zlib{true};
+    bool zlib{false};
     bool szip{false};
+    bool zstd{false};
+    bool bz2{false};
+    bool quant{false};
     bool debug{false};
     bool detect_nans{false};
     bool statistics{false};
@@ -94,7 +110,8 @@ namespace IOShell {
     bool quiet{false};
     bool in_memory_read{false};
     bool in_memory_write{false};
-    bool lower_case_variable_names{true};
+    bool lowercase_variable_names{false};
+    bool lowercase_database_names{false};
     bool delete_timesteps{false};
     bool minimize_open_files{false};
     bool disable_field_recognition{false};
@@ -114,6 +131,8 @@ namespace IOShell {
     bool delete_qa{false};
     bool delete_info{false};
     bool line_decomp{false};
+    bool sort_times{false};
+    bool shuffle_times{false};
     char fieldSuffixSeparator{'_'};
   };
 } // namespace IOShell
